@@ -344,6 +344,10 @@ def helper(opts, requirements):
         if dist.platform != index.platform:
             raise RuntimeError("Could not locate binary egg %s for %s" %
                                (dist, index.platform))
+        if opts.output not in dist.location:
+            # Copy the egg if it was not downloaded but lcoated
+            # in the filesystem
+            shutil.copy(dist.location, opts.output)
 
     
     
